/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *                    Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 *  Revision History:
 *  03/10/00:  Release version 0.1.
 *  04/17/00:  Release version 0.2. (get port from HTML tag)
 *
 *
 */

package adm;

import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import cdev.*;

/**
 * This class extends awt.Applet and contains code to connect to a cdev 
 * IOservice such as the cdevGateway. By default it connects to the port 
 * specified in the HTML PORT PARAM tag or to default port 9199 of the web 
 * server if the PORT PARAM tag is not defined. A port number also can be 
 * passed to CApplet via an init (int port) method (called, for example, 
 * by a derived class). 
 * <BR><BR>
 * CApplet implement its own start() and stop() methods to resume or suspend 
 * the IOservice when the applet becomes visible or temporarily invisible. 
 * <BR><BR>
 * If you subclass the CApplet, you only have to add widgets in the init() 
 * method, and they will appear (live) on the web page.
 *
 *
 * @version   0.2  04/17/00
 * @author    Chip Watson, Ying Chen
 *            (Based on work by Cuong Quach and Mr. John Winans)
 * @since     adm0.1
 *
 */

public class CApplet extends Applet
{
    private static int DEFAULT_PORT=9199;
    private ControlSystem sys;
    private int port;
    private boolean paused = false;
    
    /**
     * Initialize the connection to the server, try to use the port number
     * that are embeded in the HTML file. If failed, then using the 
     * default port.
     */
    public void init() {
	try {
	    port = Integer.parseInt(getParameter ("PORT"));
	}
	catch(NumberFormatException ne) {
	    System.out.println("use default port to connect the server");
	    port = DEFAULT_PORT;
	}
	init(port);
    }
    
    /**
     * Initialize the connection to the server, using the specified port.
     */
    public void init(int p)
    {
	port = p;
	String host = (getCodeBase()).getHost();
	//----------------------------------------------//
        // Connect to Control system.
        //----------------------------------------------//
        try {
            sys = ControlSystem.getDefault();
	    synchronized (sys) {
		sys.resumeIO(); // in case left sleeping
		paused = false;
		if (!sys.isConnected()) {
		    System.out.println("init connecting...");
		    sys.connect(host,port);
		}
	    }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    public void start() {
        if (sys != null && paused) try {
            sys.resumeIO();
	    System.out.println("resumed IO");
        } catch (Exception e) {
            System.out.println("applet restart failed");
            e.printStackTrace();
        }
	paused = false;
    }
    
    public void stop() {
        if (sys != null) try {
            sys.suspendIO();
	    System.out.println("paused IO");
	    paused = true;
        } catch (Exception e) {
	    System.out.println("applet suspend failed");
            e.printStackTrace();
	}
    }
}




