/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *                    Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 *
 *  Revision History:
 *  03/10/00:  Release version 0.1 (old name is CFrame)
 *  04/17/00:  Release version 0.2. (no change) 
 *  06/22/00:  Release version 0.3. (new name CApplication, closabel) 
 *
 *
 */

package adm;

import java.awt.*;
import java.awt.event.*;
import cdev.*;

/**
 * Creates an awt frame, and initializes a connection to a server, 
 * typically a gateway such as cdevGateway. Extending this class automates 
 * making this connection. 
 * <BR><BR>
 * There are four CApplication constructors. Use CApplication () and 
 * CApplication (String title) to connect to the local host and default 
 * port (9199). Use constructors CApplication (String host, int port) and 
 * CApplication (String host, int port, String title) to connect to a 
 * specific host and port. 
 * <BR><BR>
 * The window closing event is implemented in this class. Before exiting 
 * the application, CApplication disconnects from the CDEV server. 
 *
 *
 * @version   0.2  04/17/00
 * @author    Ying Chen, Chip Watson
 *            (Based on work by Cuong Quach and Mr. John Winans)
 * @since     adm0.3
 *
 */
public class CApplication extends Frame 
{
    private static int DEFAULT_PORT = 9199;
    private ControlSystem sys;
    private int port;
    private String host = null;    
 
    /**
     * Null Constructor
     */
    public CApplication ()
    {
	this("localhost",  DEFAULT_PORT);
    }


    /**
     * Constructor
     * @param title   the title of the frame
     */
    public CApplication (String title)
    {
	this("localhost",  DEFAULT_PORT);
	setTitle(title);
    }


    /**
     * Constructor
     * @param host    cdevGateway host name
     * @param port    port number cdevGateway used
     */
    public CApplication (String host, int port)
    {
	super();
	this.host = host;
        this.port = port;
        //----------------------------------------------//
        // Connect to Control system.
        //----------------------------------------------//
        try {
            sys = ControlSystem.getDefault();
            sys.connect(host,port);
        } catch (Exception e) {
            e.printStackTrace();
        }
	addWindowListener (new WindowAdapter () {
	    public void windowClosing (WindowEvent we) {
		setVisible (false);
		try { sys.disconnect (); }
		catch (Exception e) { e.printStackTrace(); }
		System.exit (0); 
	    }
	} );
    } 

    /**
     * constructor
     * @param host    cdevGateway host name
     * @param port    port number cdevGateway used
     * @param title   the title of the frame
     */
    public CApplication (String host, int port, String title)
    {
	this(host, port);
	setTitle(title);
    }


}




