/*
 * Copyright (c) 2000 Southeastern Universities Research Association,
 *                    Continuous Electron Beam Accelerator Facility
 *
 * This software was developed under a United States Government license
 * described in the NOTICE file included as part of this distribution.
 *
 *  Revision History:
 *  03/10/00:  Release version 0.1. The alignment option is implemented.
 *  04/10/00:  Release version 0.2. 
 *  05/27/00:  Release version 0.3 (deprecated)
 *
 */

package adm;

import java.awt.*;
import cdev.*;


/**
 * @deprecated    As version 0.3, replaced by CLabel class.
 * <BR><BR>
 * Displays a fixed string which can change color dynamically.
 * If the object is connected to a device property, the color of the
 * oval will track the state of the device property when CLRMOD_ALARM 
 * is set. If the foreground color is set to the color of the container, 
 * then the text will disappear when it is in the normal state.
 *
 *
 * @version   0.3  06/24/00
 * @author    Ying Chen,  Chip Watson
 *             (Based on work by Cuong Quach and Mr. John Winans)
 * @since     adm0.1
 *
 */
public class CText extends CRect {

    private static String BLANK = "";

    //--- GUI graphics info. -------------------------
    private int faceW, faceH, faceX, faceY = 0;
    
    //--- define default values ----------------------
    private String textString = BLANK;
    private int alignStyle = ALIGN_LEFT;

    /**
     *  Null Constructor.
     */
    public CText () 
    {
	super();
    }

    /**
     * Constructor with device name and property name
     *
     * @param dName    device name
     * @param pName    property name
     */
    public CText(String dName, String pName)
    {
        super(dName, pName);
    }
    
    /**
     * Constuctor.
     * @param aString   the text string on the component 
     */
    public CText (String aString) 
    {
	super();
	textString = aString;
    }
	

    /**
     * Constuctor
     * @param w   the width of the component
     * @param h   the height of the component
     */
    public CText (int w, int h) 
    {
	super(w, h);
    }


    /**
     * Constuctor.
     * @param w   the width of the component
     * @param h   the height of the component
     * @param fg  the foreground color of the component
     * @param bg  the background color of the component
     */ 
    public CText (int w, int h, Color fg, Color bg) 
    {
	super(w, h, fg, bg);
    }


    
    /**
     * Set the display text
     * @param aString   the text string on the component.
     */ 
    public void setText (String aString)
    {
	textString = aString;
    }

    /**
     * Return the display text
     */
    public String getText () { return textString; }


    /**
     * Set up align style
     * @param newAligh   the alignment style, which may be one of:
     *             <OL>
     *             <LI>  CConstants.ALIGN_LEFT
     *             <LI>  CConstants.ALIGN_CENTER
     *             <LI>  CConstants.ALIGN_RIGHT
     *             </OL>
     */
    public void setAlignStyle (int newAlign)
    {
	alignStyle = newAlign;
	initGraphics();
	repaint();
    }


    /**
     * Return display text on the component
     */
    public int getAlignStyle () { return alignStyle; }


    protected void initGraphics() 
    {
	Dimension rec = getSize();
	//FontMetrics fm = getFontMetrics(font);    //for java1.2
        FontMetrics fm = Toolkit.getDefaultToolkit().getFontMetrics(font);
        int fontH = fm.getHeight();
        int fontD = fm.getDescent();
	int fontA = fm.getAscent();
	int stringW = fm.stringWidth(textString);
	switch (alignStyle) {
	case ALIGN_CENTER:
	    faceX = (int)((rec.width - stringW)/2);
	    break;
	case ALIGN_RIGHT:
	    faceX = rec.width - stringW;
	    break;
	default:     //case ALIGN_LEFT:
	    faceX = 0;
	    break;
	}

	faceX = Math.max (faceX, 0);
        faceY = (int) (rec.height/2) + (int)(fontH-fontA+fontD)/2;
	faceW = rec.width;
	faceH = rec.height;
    }

    
    public void paint (Graphics g) 
    {
	if (firstTime) 
	    initGraphics();
	g.setColor(getParent().getBackground());
	g.fillRect(0, 0, faceW, faceH);
	//--- draw new text string -------------------
	Color c = g.getColor();
        if (c != currColor) {
	    g.setColor(currColor);
	    g.setFont(font);
            g.drawString(textString, faceX, faceY);
	}
    }
     
} //end of CText





